# Generated by Django 4.2.15 on 2024-10-09 20:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("metenox", "0003_remove_metenox_tag_metenox_tags_metenoxtag_default"),
    ]

    operations = [
        migrations.AlterField(
            model_name="metenox",
            name="tags",
            field=models.ManyToManyField(
                blank=True,
                help_text="Tags assigned to a Metenox",
                to="metenox.metenoxtag",
            ),
        ),
    ]
