{% load i18n %}
{% if perms.metenox.view_moons %}
    <li class="nav-item">
        <a class="nav-link" aria-current="page" href="{% url 'metenox:index' %}"><i class="fa-solid fa-moon fa-fw"></i> {% translate "Moons" %}</a>
    </li>
{% endif %}
{% if perms.metenox.view_metenoxes %}
    <li class="nav-item">
        <a class="nav-link"
           aria-current="page"
           href="{% url 'metenox:metenoxes' %}"><i class="fas fa-oil-well fa-fw"></i> {% translate "Metenoxes" %}</a>
    </li>
    <li class="nav-item">
        <a class="nav-link"
           aria-current="page"
           href="{% url 'metenox:corporations' %}"><i class="fa-solid fa-building fa-fw"></i> {% translate "Corporations" %}</a>
    </li>
{% endif %}
<li>
    <a class="nav-link"
       aria-current="page"
       href="{% url 'metenox:prices' %}"><i class="fa-solid fa-dollar-sign fa-fw"></i> {% translate "Prices" %}</a>
</li>
