{% load static %}
{% include "metenox/partials/metenox_details_moon.html" %}
<br>
{% include "metenox/partials/metenox_details_stored_products.html" %}
<br>
{% include "metenox/partials/moon_details_products.html" %}
