{% load i18n %}
{% load metenox %}
<h2>{{ corporation.corporation_name }}</h2>
<table class="table">
    <thead>
        <tr>
            <th scope="col">{% translate "Tag name" %}</th>
            <th scope="col">{% translate "Number of metenoxes" %}</th>
            <th scope="col">{% translate "Raw revenue" %}</th>
            <th scope="col">{% translate "Profit" %}</th>
        </tr>
    </thead>
    <tbody>
        {% for tag_name, values in tags.items %}
            <tr>
                <th>{{ tag_name }}</th>
                <th>{{ values.count }}</th>
                <th>{{ values.raw_profit | formatisk }}</th>
                <th>{{ values.revenue | formatisk }}</th>
            </tr>
        {% endfor %}
    </tbody>
</table>
