# Generated by Django 4.2.16 on 2025-02-28 18:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("metenox", "0004_alter_metenox_tags"),
    ]

    operations = [
        migrations.AddField(
            model_name="metenox",
            name="last_updated",
            field=models.DateTimeField(auto_now=True),
        ),
        migrations.AlterField(
            model_name="metenox",
            name="tags",
            field=models.ManyToManyField(
                blank=True,
                help_text="Tags assigned to a Metenox",
                related_name="metenoxes",
                to="metenox.metenoxtag",
            ),
        ),
        migrations.AlterField(
            model_name="metenoxtag",
            name="name",
            field=models.CharField(max_length=20, unique=True),
        ),
    ]
