# Generated by Django 4.2.16 on 2025-03-12 23:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("metenox", "0005_metenox_last_updated_alter_metenox_tags_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="holdingcorporation",
            name="ping_on_value_in_moongoo_bay",
            field=models.IntegerField(
                blank=True,
                help_text="Ping should be sent when the value stored in the moon bay of a Metenox exceed this value",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="holdingcorporation",
            name="ping_on_volume_in_moongoo_bay",
            field=models.IntegerField(
                blank=True,
                help_text="Ping should be sent when the volume stored in the moon goo bay of a Metenox exceed this value.",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="metenox",
            name="last_moongoo_bay_ping",
            field=models.DateTimeField(
                help_text="Last time that a ping was sent about the moon goo bay exceeding the threshold",
                null=True,
            ),
        ),
    ]
